@@ -61,10 +61,10 @@ static size_t bufsize;
  * (gtags.conf, $HOME/.globalrc) if it is defined.
  */
 #if defined(USE_EXTRA_FIELDS)
-static const char *ctagscom = UNIVERSAL_CTAGS;
+static char *ctagscom = UNIVERSAL_CTAGS;
 static const char *ctagsnotfound = "Universal Ctags not found. Please see ./configure --help.";
 #else
-static const char *ctagscom = EXUBERANT_CTAGS;
+static char *ctagscom = EXUBERANT_CTAGS;
 static const char *ctagsnotfound = "Exuberant Ctags not found. Please see ./configure --help.";
 #endif
 
@@ -200,6 +200,7 @@ start_ctags(const struct parser_param *param)
 		ctagscom = path;
 	if (!ctagscom || !strlen(ctagscom) || !strcmp(ctagscom, "no"))
 		param->die(ctagsnotfound);
+	argv[0] = ctagscom;
 	argv[1] = malloc(sizeof(LANGMAP_OPTION) + strlen(param->langmap));
 	if (argv[1] == NULL)
 		param->die("short of memory.");
